pub struct ThreadPriority { /* private fields */ }Implementations
Sourceimpl ThreadPriority
impl ThreadPriority
pub const PLATFORM_MIN: Self
pub const PLATFORM_MAX: Self
pub const DEFAULT: Self
pub const LOW: Self
pub const MEDIUM: Self
pub const HIGH: Self
pub const VERY_HIGH: Self
pub const EXTREME: Self
pub const CRITICAL: Self
pub const MIXER: Self
pub const FEEDER: Self
pub const STREAM: Self
pub const FILE: Self
pub const NONBLOCKING: Self
pub const RECORD: Self
pub const GEOMETRY: Self
pub const PROFILER: Self
pub const STUDIO_UPDATE: Self
pub const STUDIO_LOAD_BANK: Self
pub const STUDIO_LOAD_SAMPLE: Self
pub const CONVOLUTION1: Self
pub const CONVOLUTION2: Self
Sourcepub const fn bits(&self) -> FMOD_THREAD_PRIORITY
pub const fn bits(&self) -> FMOD_THREAD_PRIORITY
Returns the raw value of the flags currently stored.
Sourcepub const fn from_bits(bits: FMOD_THREAD_PRIORITY) -> Option<Self>
pub const fn from_bits(bits: FMOD_THREAD_PRIORITY) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
Sourcepub const fn from_bits_truncate(bits: FMOD_THREAD_PRIORITY) -> Self
pub const fn from_bits_truncate(bits: FMOD_THREAD_PRIORITY) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
Sourcepub const unsafe fn from_bits_unchecked(bits: FMOD_THREAD_PRIORITY) -> Self
pub const unsafe fn from_bits_unchecked(bits: FMOD_THREAD_PRIORITY) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.